@@ -1,3 +1,5 @@
+// Package installer implements functions that provide a first-time
+// installation wizard.
 package installer
 
 import (
@@ -14,7 +16,7 @@ func Prompt(prompt string, def bool) (bool, error) {
 	reader := bufio.NewReader(os.Stdin)
 
 	// display the prompt
-	fmt.Print(fmt.Sprintf("%s: ", prompt))
+	fmt.Printf("%s: ", prompt)
 
 	// read the answer
 	ans, err := reader.ReadString('\n')
